@@ -14,7 +14,7 @@ use Validation::Class::Fields;
 use Validation::Class::Errors;
 use Validation::Class::Util;
 
-our $VERSION = '7.900027'; # VERSION
+our $VERSION = '7.900028'; # VERSION
 
 use Hash::Flatten 'flatten', 'unflatten';
 use Module::Runtime 'use_module';
@@ -488,6 +488,17 @@ sub clone_field {
 }
 
 
+sub does {
+
+    my ($self, $role) = @_;
+
+    my $roles = $self->settings->get('roles');
+
+    return $roles ? (firstval { $_ eq $role } @{$roles}) ? 1 : 0 : 0;
+
+}
+
+
 sub error_count {
 
     my ($self) = @_;
@@ -2073,7 +2084,7 @@ Validation::Class::Prototype - Data Validation Engine for Validation::Class Clas
 
 =head1 VERSION
 
-version 7.900027
+version 7.900028
 
 =head1 DESCRIPTION
 
@@ -2337,6 +2348,23 @@ validated that can share existing validation rules.
 
     1;
 
+=head2 does
+
+The does method is used to determine whether the current prototype is composed
+using the role specified. Return true if so, false if not.
+
+    package Class;
+
+    use Validation::Class;
+
+    set role => 'Class::Root';
+
+    package main;
+
+    my $self = Class->new(params => $params);
+
+    return 1 if $self->proto->does('Class::Root');
+
 =head2 error_count
 
 The error_count method returns the total number of errors set at both the class
